
TODO: TODO_23_17_31_04: publish `index_model` by delegator plugins

Even if FS_45_08_22_15 `index_model` is data (not logic), it is better to define it by delegator.
Why?

There are few reasons:

*   Delegator describes `func_id`-s it supports with `search_control` for them.

    This describes data just like `index_model` describes it.

*   There are plans to switch from internal data loaders to external ones.

    It could be the case that most (if not all) of the data (except func `data_envelope`-s) will be loaded
    via external loaders - creating internal loader plugins just to declare `index_model` seems contrived.

    Exposing API for DML (in addition to DDL) to let external, on the other hand, seems unnecessary now.

*   If we get rid of the need to have internal loaders, the only internal plugin type to define would be delegator.

    It may become streamlined use case when only delegator need to be implemented & configured for the server.    
